@@ -1,6 +1,6 @@
 """Alconna 命令行入口"""
 
-from arclet.alconna_cli.commandline import alc_cli
+from arclet.alconna_cli import alc_cli
 
 if __name__ == "__main__":
     main = alc_cli.main
